import _arrayMap from './_arrayMap.js';
import _copyArray from './_copyArray.js';
import isArray_1 from './isArray.js';
import isSymbol_1 from './isSymbol.js';
import _stringToPath from './_stringToPath.js';
import _toKey from './_toKey.js';
import toString_1 from './toString.js';
var arrayMap = _arrayMap,
    copyArray = _copyArray,
    isArray = isArray_1,
    isSymbol = isSymbol_1,
    stringToPath = _stringToPath,
    toKey = _toKey,
    toString = toString_1;
/**
 * Converts `value` to a property path array.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Util
 * @param {*} value The value to convert.
 * @returns {Array} Returns the new property path array.
 * @example
 *
 * _.toPath('a.b.c');
 * // => ['a', 'b', 'c']
 *
 * _.toPath('a[0].b.c');
 * // => ['a', '0', 'b', 'c']
 */

function toPath(value) {
  if (isArray(value)) {
    return arrayMap(value, toKey);
  }

  return isSymbol(value) ? [value] : copyArray(stringToPath(toString(value)));
}

var toPath_1 = toPath;
export { toPath_1 as default };
//# sourceMappingURL=toPath.js.map
